// Copyright (C) 2016 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#ifndef QIOSAPPLICATIONDELEGATE_H
#define QIOSAPPLICATIONDELEGATE_H

#import <UIKit/UIKit.h>
#import <QtGui/QtGui>

#import "qiosviewcontroller.h"

@interface QIOSApplicationDelegate : UIResponder <UIApplicationDelegate>
@end

#endif // QIOSAPPLICATIONDELEGATE_H
